@@ -188,8 +188,8 @@ do_perf(gint argc, gchar **argv)
 		camel_mime_filter_index_set_name (
 			CAMEL_MIME_FILTER_INDEX (filter_index), idn);
 		name = g_strdup_printf("%s/%s", path, d->d_name);
-		stream = camel_stream_fs_new_with_name(name, O_RDONLY, 0);
-		camel_stream_write_to_stream(stream, filter);
+		stream = camel_stream_fs_new_with_name(name, O_RDONLY, 0, NULL);
+		camel_stream_write_to_stream(stream, filter, NULL);
 		g_object_unref (stream);
 		g_free(name);
 
