@@ -5,7 +5,7 @@
  * Author:
  *  Dan Winship <danw@ximian.com>
  *
- * Copyright 2000 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -37,14 +37,9 @@
 #include <sys/stat.h>
 #include <sys/uio.h>
 
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-
-#include <glib.h>
+#include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
-#include "camel-exception.h"
 #include "camel-lock-client.h"
 #include "camel-mime-filter-from.h"
 #include "camel-mime-filter.h"
@@ -56,27 +51,27 @@
 #ifdef MOVEMAIL_PATH
 #include <sys/wait.h>
 
-static void movemail_external (const char *source, const char *dest,
-			       CamelException *ex);
+static void movemail_external (const gchar *source, const gchar *dest,
+			       GError **error);
 #endif
 
 #ifdef HAVE_BROKEN_SPOOL
-static int camel_movemail_copy_filter(int fromfd, int tofd, off_t start, size_t bytes, CamelMimeFilter *filter);
-static int camel_movemail_solaris (int oldsfd, int dfd, CamelException *ex);
+static gint camel_movemail_copy_filter(gint fromfd, gint tofd, goffset start, gsize bytes, CamelMimeFilter *filter);
+static gint camel_movemail_solaris (gint oldsfd, gint dfd, GError **error);
 #else
 /* these could probably be exposed as a utility? (but only mbox needs it) */
-static int camel_movemail_copy_file(int sfd, int dfd, CamelException *ex);
+static gint camel_movemail_copy_file(gint sfd, gint dfd, GError **error);
 #endif
 
 #if 0
-static int camel_movemail_copy(int fromfd, int tofd, off_t start, size_t bytes);
+static gint camel_movemail_copy(gint fromfd, gint tofd, goffset start, gsize bytes);
 #endif
 
 /**
  * camel_movemail:
  * @source: source file
  * @dest: destination file
- * @ex: a CamelException
+ * @error: return location for a #GError, or %NULL
  *
  * This copies an mbox file from a shared directory with multiple
  * readers and writers into a private (presumably Camel-controlled)
@@ -85,12 +80,14 @@ static int camel_movemail_copy(int fromfd, int tofd, off_t start, size_t bytes);
  *
  * Return Value: Returns -1 on error.
  **/
-int
-camel_movemail(const char *source, const char *dest, CamelException *ex)
+gint
+camel_movemail (const gchar *source,
+                const gchar *dest,
+                GError **error)
 {
-	int lockid = -1;
-	int res = -1;
-	int sfd, dfd;
+	gint lockid = -1;
+	gint res = -1;
+	gint sfd, dfd;
 	struct stat st;
 
 	/* Stat and then open the spool file. If it doesn't exist or
@@ -100,12 +97,13 @@ camel_movemail(const char *source, const char *dest, CamelException *ex)
 	 * assuming it's unlocked is equivalent to pretending we were
 	 * called a fraction earlier.)
 	 */
-	if (stat (source, &st) == -1) {
-		if (errno != ENOENT) {
-			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-					      _("Could not check mail file %s: %s"),
-					      source, g_strerror (errno));
-		}
+	if (g_stat (source, &st) == -1) {
+		if (errno != ENOENT)
+			g_set_error (
+				error, G_IO_ERROR,
+				g_io_error_from_errno (errno),
+				_("Could not check mail file %s: %s"),
+				source, g_strerror (errno));
 		return -1;
 	}
 
@@ -115,24 +113,27 @@ camel_movemail(const char *source, const char *dest, CamelException *ex)
 	/* open files */
 	sfd = open (source, O_RDWR);
 	if (sfd == -1) {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-				      _("Could not open mail file %s: %s"),
-				      source, g_strerror (errno));
+		g_set_error (
+			error, G_IO_ERROR,
+			g_io_error_from_errno (errno),
+			_("Could not open mail file %s: %s"),
+			source, g_strerror (errno));
 		return -1;
 	}
 
 	dfd = open (dest, O_WRONLY | O_CREAT | O_APPEND, S_IRUSR | S_IWUSR);
 	if (dfd == -1) {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-				      _("Could not open temporary mail "
-					"file %s: %s"), dest,
-				      g_strerror (errno));
+		g_set_error (
+			error, G_IO_ERROR,
+			g_io_error_from_errno (errno),
+			_("Could not open temporary mail file %s: %s"),
+			dest, g_strerror (errno));
 		close (sfd);
 		return -1;
 	}
 
 	/* lock our source mailbox */
-	lockid = camel_lock_helper_lock(source, ex);
+	lockid = camel_lock_helper_lock(source, error);
 	if (lockid == -1) {
 		close(sfd);
 		close(dfd);
@@ -142,7 +143,7 @@ camel_movemail(const char *source, const char *dest, CamelException *ex)
 #ifdef HAVE_BROKEN_SPOOL
 	res = camel_movemail_solaris(sfd, dfd, ex);
 #else
-	res = camel_movemail_copy_file(sfd, dfd, ex);
+	res = camel_movemail_copy_file(sfd, dfd, error);
 #endif
 
 	/* If no errors occurred copying the data, and we successfully
@@ -152,9 +153,11 @@ camel_movemail(const char *source, const char *dest, CamelException *ex)
 		if (close (dfd) == 0) {
 			ftruncate (sfd, 0);
 		} else {
-			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-					      _("Failed to store mail in temp file %s: %s"),
-					      dest, g_strerror (errno));
+			g_set_error (
+				error, G_IO_ERROR,
+				g_io_error_from_errno (errno),
+				_("Failed to store mail in temp file %s: %s"),
+				dest, g_strerror (errno));
 			res = -1;
 		}
 	} else
@@ -168,12 +171,14 @@ camel_movemail(const char *source, const char *dest, CamelException *ex)
 
 #ifdef MOVEMAIL_PATH
 static void
-movemail_external (const char *source, const char *dest, CamelException *ex)
+movemail_external (const gchar *source,
+                   const gchar *dest,
+                   GError **error)
 {
 	sigset_t mask, omask;
 	pid_t pid;
-	int fd[2], len = 0, nread, status;
-	char buf[BUFSIZ], *output = NULL;
+	gint fd[2], len = 0, nread, status;
+	gchar buf[BUFSIZ], *output = NULL;
 
 	/* Block SIGCHLD so the app can't mess us up. */
 	sigemptyset (&mask);
@@ -182,9 +187,11 @@ movemail_external (const char *source, const char *dest, CamelException *ex)
 
 	if (pipe (fd) == -1) {
 		sigprocmask (SIG_SETMASK, &omask, NULL);
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-				      _("Could not create pipe: %s"),
-				      g_strerror (errno));
+		g_set_error (
+			error, G_IO_ERROR,
+			g_io_error_from_errno (errno),
+			_("Could not create pipe: %s"),
+			g_strerror (errno));
 		return;
 	}
 
@@ -194,9 +201,10 @@ movemail_external (const char *source, const char *dest, CamelException *ex)
 		close (fd[0]);
 		close (fd[1]);
 		sigprocmask (SIG_SETMASK, &omask, NULL);
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-				      _("Could not fork: %s"),
-				      g_strerror (errno));
+		g_set_error (
+			error, G_IO_ERROR,
+			g_io_error_from_errno (errno),
+			_("Could not fork: %s"), g_strerror (errno));
 		return;
 
 	case 0:
@@ -232,23 +240,26 @@ movemail_external (const char *source, const char *dest, CamelException *ex)
 	sigprocmask (SIG_SETMASK, &omask, NULL);
 
 	if (!WIFEXITED (status) || WEXITSTATUS (status) != 0) {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-				      _("Movemail program failed: %s"),
-				      output ? output : _("(Unknown error)"));
+		g_set_error (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
+			_("Movemail program failed: %s"),
+			output ? output : _("(Unknown error)"));
 	}
 	g_free (output);
 }
 #endif
 
 #ifndef HAVE_BROKEN_SPOOL
-static int
-camel_movemail_copy_file(int sfd, int dfd, CamelException *ex)
+static gint
+camel_movemail_copy_file (gint sfd,
+                          gint dfd,
+                          GError **error)
 {
-	int nread, nwrote;
-	char buf[4096];
+	gint nread, nwrote;
+	gchar buf[4096];
 
 	while (1) {
-		int written = 0;
+		gint written = 0;
 
 		nread = read (sfd, buf, sizeof (buf));
 		if (nread == 0)
@@ -256,9 +267,11 @@ camel_movemail_copy_file(int sfd, int dfd, CamelException *ex)
 		else if (nread == -1) {
 			if (errno == EINTR)
 				continue;
-			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-					      _("Error reading mail file: %s"),
-					      g_strerror (errno));
+			g_set_error (
+				error, G_IO_ERROR,
+				g_io_error_from_errno (errno),
+				_("Error reading mail file: %s"),
+				g_strerror (errno));
 			return -1;
 		}
 
@@ -267,9 +280,11 @@ camel_movemail_copy_file(int sfd, int dfd, CamelException *ex)
 			if (nwrote == -1) {
 				if (errno == EINTR)
 					continue; /* continues inner loop */
-				camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-						      _("Error writing mail temp file: %s"),
-						      g_strerror (errno));
+				g_set_error (
+					error, G_IO_ERROR,
+					g_io_error_from_errno (errno),
+					_("Error writing mail temp file: %s"),
+					g_strerror (errno));
 				return -1;
 			}
 			written += nwrote;
@@ -282,11 +297,11 @@ camel_movemail_copy_file(int sfd, int dfd, CamelException *ex)
 #endif
 
 #if 0
-static int
-camel_movemail_copy(int fromfd, int tofd, off_t start, size_t bytes)
+static gint
+camel_movemail_copy(gint fromfd, gint tofd, goffset start, gsize bytes)
 {
-        char buffer[4096];
-        int written = 0;
+        gchar buffer[4096];
+        gint written = 0;
 
 	d(printf("writing %d bytes ... ", bytes));
 
@@ -294,7 +309,7 @@ camel_movemail_copy(int fromfd, int tofd, off_t start, size_t bytes)
 		return -1;
 
         while (bytes>0) {
-                int toread, towrite;
+                gint toread, towrite;
 
                 toread = bytes;
                 if (bytes>4096)
@@ -334,13 +349,13 @@ camel_movemail_copy(int fromfd, int tofd, off_t start, size_t bytes)
 #define PRE_SIZE (32)
 
 #ifdef HAVE_BROKEN_SPOOL
-static int
-camel_movemail_copy_filter(int fromfd, int tofd, off_t start, size_t bytes, CamelMimeFilter *filter)
+static gint
+camel_movemail_copy_filter(gint fromfd, gint tofd, goffset start, gsize bytes, CamelMimeFilter *filter)
 {
-        char buffer[4096+PRE_SIZE];
-        int written = 0;
-	char *filterbuffer;
-	int filterlen, filterpre;
+        gchar buffer[4096+PRE_SIZE];
+        gint written = 0;
+	gchar *filterbuffer;
+	gint filterlen, filterpre;
 
 	d(printf("writing %d bytes ... ", bytes));
 
@@ -350,7 +365,7 @@ camel_movemail_copy_filter(int fromfd, int tofd, off_t start, size_t bytes, Came
 		return -1;
 
         while (bytes>0) {
-                int toread, towrite;
+                gint toread, towrite;
 
                 toread = bytes;
                 if (bytes>4096)
@@ -400,11 +415,11 @@ camel_movemail_copy_filter(int fromfd, int tofd, off_t start, size_t bytes, Came
 
 /* write the headers back out again, but not he Content-Length header, because we dont
    want	to maintain it! */
-static int
-solaris_header_write(int fd, struct _camel_header_raw *header)
+static gint
+solaris_header_write(gint fd, struct _camel_header_raw *header)
 {
         struct iovec iv[4];
-        int outlen = 0, len;
+        gint outlen = 0, len;
 
         iv[1].iov_base = ":";
         iv[1].iov_len = 1;
@@ -417,11 +432,11 @@ solaris_header_write(int fd, struct _camel_header_raw *header)
 			iv[0].iov_len = strlen(header->name);
 			iv[2].iov_base = header->value;
 			iv[2].iov_len = strlen(header->value);
-		
+
 			do {
 				len = writev(fd, iv, 4);
 			} while (len == -1 && errno == EINTR);
-			
+
 			if (len == -1)
 				return -1;
 			outlen += len;
@@ -446,23 +461,27 @@ solaris_header_write(int fd, struct _camel_header_raw *header)
 /* Well, since Solaris is a tad broken wrt its 'mbox' folder format,
    we must convert it to a real mbox format.  Thankfully this is
    mostly pretty easy */
-static int
-camel_movemail_solaris (int oldsfd, int dfd, CamelException *ex)
+static gint
+camel_movemail_solaris (gint oldsfd,
+                        gint dfd,
+                        GError **error)
 {
 	CamelMimeParser *mp;
-	char *buffer;
-	int len;
-	int sfd;
-	CamelMimeFilterFrom *ffrom;
-	int ret = 1;
-	char *from = NULL;
+	gchar *buffer;
+	gint len;
+	gint sfd;
+	CamelMimeFilter *ffrom;
+	gint ret = 1;
+	gchar *from = NULL;
 
 	/* need to dup as the mime parser will close on finish */
 	sfd = dup(oldsfd);
 	if (sfd == -1) {
-		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-				      _("Error copying mail temp file: %s"),
-				      g_strerror (errno));
+		g_set_error (
+			error, G_IO_ERROR,
+			g_io_error_from_errno (errno),
+			_("Error copying mail temp file: %s"),
+			g_strerror (errno));
 		return -1;
 	}
 
@@ -476,10 +495,10 @@ camel_movemail_solaris (int oldsfd, int dfd, CamelException *ex)
 		g_assert(camel_mime_parser_from_line(mp));
 		from = g_strdup(camel_mime_parser_from_line(mp));
 		if (camel_mime_parser_step(mp, &buffer, &len) != CAMEL_MIME_PARSER_STATE_FROM_END) {
-			const char *cl;
-			int length;
-			int start, body;
-			off_t newpos;
+			const gchar *cl;
+			gint length;
+			gint start, body;
+			goffset newpos;
 
 			ret = 0;
 
@@ -495,7 +514,7 @@ camel_movemail_solaris (int oldsfd, int dfd, CamelException *ex)
 
 			cl = camel_mime_parser_header(mp, "content-length", NULL);
 			if (cl == NULL) {
-				g_warning("Required Content-Length header is missing from solaris mail box @ %d", (int)camel_mime_parser_tell(mp));
+				g_warning("Required Content-Length header is missing from solaris mail box @ %d", (gint)camel_mime_parser_tell(mp));
 				camel_mime_parser_drop_step(mp);
 				camel_mime_parser_drop_step(mp);
 				camel_mime_parser_step(mp, &buffer, &len);
@@ -509,7 +528,7 @@ camel_movemail_solaris (int oldsfd, int dfd, CamelException *ex)
 				newpos = length+body;
 			}
 			/* copy body->length converting From lines */
-			if (camel_movemail_copy_filter(sfd, dfd, body, length, (CamelMimeFilter *)ffrom) == -1)
+			if (camel_movemail_copy_filter(sfd, dfd, body, length, ffrom) == -1)
 				goto fail;
 			if (newpos != -1)
 				camel_mime_parser_seek(mp, newpos, SEEK_SET);
@@ -519,21 +538,22 @@ camel_movemail_solaris (int oldsfd, int dfd, CamelException *ex)
 		g_free(from);
 	}
 
-	camel_object_unref((CamelObject *)mp);
-	camel_object_unref((CamelObject *)ffrom);
+	g_object_unref (mp);
+	g_object_unref (ffrom);
 
 	return ret;
 
 fail:
 	g_free(from);
 
-	camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-			      _("Error copying mail temp file: %s"),
-			      g_strerror (errno));
+	g_set_error (
+		error, G_IO_ERROR,
+		g_io_error_from_errno (errno),
+		_("Error copying mail temp file: %s"),
+		g_strerror (errno));
 
-
-	camel_object_unref((CamelObject *)mp);
-	camel_object_unref((CamelObject *)ffrom);
+	g_object_unref (mp);
+	g_object_unref (ffrom);
 
 	return -1;
 }
