@@ -46,83 +46,41 @@
 #endif
 
 /* Specified in RFC 1939 */
-#define POP3_PORT "110"
-#define POP3S_PORT "995"
+#define POP3_PORT  110
+#define POP3S_PORT 995
 
 /* defines the length of the server error message we can display in the error dialog */
 #define POP3_ERROR_SIZE_LIMIT 60
 
-static gpointer camel_pop3_store_parent_class;
-
-static gboolean pop3_connect (CamelService *service, CamelException *ex);
-static gboolean pop3_disconnect (CamelService *service, gboolean clean, CamelException *ex);
-static GList *query_auth_types (CamelService *service, CamelException *ex);
-
-static CamelFolder *get_folder (CamelStore *store, const gchar *folder_name,
-				guint32 flags, CamelException *ex);
-
-static CamelFolder *get_trash  (CamelStore *store, CamelException *ex);
-
-static gboolean pop3_can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelException *ex);
-
-G_DEFINE_TYPE (CamelPOP3Store, camel_pop3_store, CAMEL_TYPE_STORE)
-
-static void
-pop3_store_finalize (GObject *object)
-{
-	CamelPOP3Store *pop3_store = CAMEL_POP3_STORE (object);
-
-	/* force disconnect so we dont have it run later, after we've cleaned up some stuff */
-	/* SIGH */
-
-	camel_service_disconnect((CamelService *)pop3_store, TRUE, NULL);
-
-	if (pop3_store->engine)
-		g_object_unref (pop3_store->engine);
-	if (pop3_store->cache)
-		g_object_unref (pop3_store->cache);
-
-	/* Chain up to parent's finalize() method. */
-	G_OBJECT_CLASS (camel_pop3_store_parent_class)->finalize (object);
-}
-
-static void
-camel_pop3_store_class_init (CamelPOP3StoreClass *class)
-{
-	GObjectClass *object_class;
-	CamelServiceClass *service_class;
-	CamelStoreClass *store_class;
-
-	object_class = G_OBJECT_CLASS (class);
-	object_class->finalize = pop3_store_finalize;
-
-	service_class = CAMEL_SERVICE_CLASS (class);
-	service_class->query_auth_types = query_auth_types;
-	service_class->connect = pop3_connect;
-	service_class->disconnect = pop3_disconnect;
-
-	store_class = CAMEL_STORE_CLASS (class);
-	store_class->get_folder = get_folder;
-	store_class->get_trash = get_trash;
-	store_class->can_refresh_folder = pop3_can_refresh_folder;
-}
-
-static void
-camel_pop3_store_init (CamelPOP3Store *pop3_store)
-{
-}
-
 enum {
 	MODE_CLEAR,
 	MODE_SSL,
 	MODE_TLS
 };
 
-#ifdef HAVE_SSL
+#ifdef CAMEL_HAVE_SSL
 #define SSL_PORT_FLAGS (CAMEL_TCP_STREAM_SSL_ENABLE_SSL2 | CAMEL_TCP_STREAM_SSL_ENABLE_SSL3)
 #define STARTTLS_FLAGS (CAMEL_TCP_STREAM_SSL_ENABLE_TLS)
 #endif
 
+static struct {
+	const gchar *value;
+	const gchar *serv;
+	gint fallback_port;
+	gint mode;
+} ssl_options[] = {
+	{ "",              "pop3s", POP3S_PORT, MODE_SSL   },  /* really old (1.x) */
+	{ "always",        "pop3s", POP3S_PORT, MODE_SSL   },
+	{ "when-possible", "pop3",  POP3_PORT,  MODE_TLS   },
+	{ "never",         "pop3",  POP3_PORT,  MODE_CLEAR },
+	{ NULL,            "pop3",  POP3_PORT,  MODE_CLEAR },
+};
+
+extern CamelServiceAuthType camel_pop3_password_authtype;
+extern CamelServiceAuthType camel_pop3_apop_authtype;
+
+G_DEFINE_TYPE (CamelPOP3Store, camel_pop3_store, CAMEL_TYPE_STORE)
+
 /* returns error message with ': ' as prefix */
 static gchar *
 get_valid_utf8_error (const gchar *text)
@@ -145,9 +103,9 @@ get_valid_utf8_error (const gchar *text)
 
 static gboolean
 connect_to_server (CamelService *service,
-                   struct addrinfo *ai,
+		   const char *host, const char *serv, gint fallback_port,
                    gint ssl_mode,
-                   CamelException *ex)
+                   GError **error)
 {
 	CamelPOP3Store *store = CAMEL_POP3_STORE (service);
 	CamelSession *session;
@@ -161,20 +119,21 @@ connect_to_server (CamelService *service,
 	const gchar *delete_days;
 
 	if (ssl_mode != MODE_CLEAR) {
-#ifdef HAVE_SSL
+#ifdef CAMEL_HAVE_SSL
 		if (ssl_mode == MODE_TLS) {
 			tcp_stream = camel_tcp_stream_ssl_new_raw (service->session, service->url->host, STARTTLS_FLAGS);
 		} else {
 			tcp_stream = camel_tcp_stream_ssl_new (service->session, service->url->host, SSL_PORT_FLAGS);
 		}
 #else
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,
+		g_set_error (
+			error, CAMEL_SERVICE_ERROR,
+			CAMEL_SERVICE_ERROR_UNAVAILABLE,
 			_("Could not connect to %s: %s"),
 			service->url->host, _("SSL unavailable"));
 
 		return FALSE;
-#endif /* HAVE_SSL */
+#endif /* CAMEL_HAVE_SSL */
 	} else
 		tcp_stream = camel_tcp_stream_raw_new ();
 
@@ -186,24 +145,13 @@ connect_to_server (CamelService *service,
 		g_free (socks_host);
 	}
 
-	if ((ret = camel_tcp_stream_connect ((CamelTcpStream *) tcp_stream, ai)) == -1) {
-		if (errno == EINTR)
-			camel_exception_set (
-				ex, CAMEL_EXCEPTION_USER_CANCEL,
-				_("Connection canceled"));
-		else
-			camel_exception_setv (
-				ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,
-				_("Could not connect to %s: %s"),
-				service->url->host, g_strerror (errno));
-
+	if (camel_tcp_stream_connect ((CamelTcpStream *) tcp_stream, host, serv, fallback_port, error) == -1) {
 		g_object_unref (tcp_stream);
-
 		return FALSE;
 	}
 
 	/* parent class connect initialization */
-	if (CAMEL_SERVICE_CLASS (camel_pop3_store_parent_class)->connect (service, ex) == FALSE) {
+	if (CAMEL_SERVICE_CLASS (camel_pop3_store_parent_class)->connect (service, error) == FALSE) {
 		g_object_unref (tcp_stream);
 		return FALSE;
 	}
@@ -215,8 +163,8 @@ connect_to_server (CamelService *service,
 		store->delete_after =  atoi(delete_days);
 
 	if (!(store->engine = camel_pop3_engine_new (tcp_stream, flags))) {
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_SYSTEM,
+		g_set_error (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
 			_("Failed to read a valid greeting from POP server %s"),
 			service->url->host);
 		g_object_unref (tcp_stream);
@@ -228,13 +176,13 @@ connect_to_server (CamelService *service,
 		return TRUE;
 	}
 
-#ifdef HAVE_SSL
+#ifdef CAMEL_HAVE_SSL
 	/* as soon as we send a STLS command, all hope is lost of a clean QUIT if problems arise */
 	clean_quit = FALSE;
 
 	if (!(store->engine->capa & CAMEL_POP3_CAP_STLS)) {
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_SYSTEM,
+		g_set_error (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
 			_("Failed to connect to POP server %s in secure mode: %s"),
 			service->url->host, _("STLS not supported by server"));
 		goto stls_exception;
@@ -251,8 +199,8 @@ connect_to_server (CamelService *service,
 		gchar *tmp;
 
 		tmp = get_valid_utf8_error ((gchar *) store->engine->line);
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_SYSTEM,
+		g_set_error (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
 			/* Translators: Last %s is an optional explanation beginning with ": " separator */
 			_("Failed to connect to POP server %s in secure mode%s"),
 			service->url->host, (tmp != NULL) ? tmp : "");
@@ -264,18 +212,19 @@ connect_to_server (CamelService *service,
 	ret = camel_tcp_stream_ssl_enable_ssl (CAMEL_TCP_STREAM_SSL (tcp_stream));
 
 	if (ret == -1) {
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_SYSTEM,
+		g_set_error (
+			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
 			_("Failed to connect to POP server %s in secure mode: %s"),
 			service->url->host, _("TLS negotiations failed"));
 		goto stls_exception;
 	}
 #else
-	camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
+	g_set_error (
+		error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
 		_("Failed to connect to POP server %s in secure mode: %s"),
 		service->url->host, _("TLS is not available in this build"));
 	goto stls_exception;
-#endif /* HAVE_SSL */
+#endif /* CAMEL_HAVE_SSL */
 
 	g_object_unref (tcp_stream);
 
@@ -301,28 +250,14 @@ connect_to_server (CamelService *service,
 	return FALSE;
 }
 
-static struct {
-	const gchar *value;
-	const gchar *serv;
-	const gchar *port;
-	gint mode;
-} ssl_options[] = {
-	{ "",              "pop3s", POP3S_PORT, MODE_SSL   },  /* really old (1.x) */
-	{ "always",        "pop3s", POP3S_PORT, MODE_SSL   },
-	{ "when-possible", "pop3",  POP3_PORT,  MODE_TLS   },
-	{ "never",         "pop3",  POP3_PORT,  MODE_CLEAR },
-	{ NULL,            "pop3",  POP3_PORT,  MODE_CLEAR },
-};
-
 static gboolean
 connect_to_server_wrapper (CamelService *service,
-                           CamelException *ex)
+                           GError **error)
 {
-	struct addrinfo hints, *ai;
 	const gchar *ssl_mode;
-	gint mode, ret, i;
+	gint mode, i;
 	gchar *serv;
-	const gchar *port;
+	gint fallback_port;
 
 	if ((ssl_mode = camel_url_get_param (service->url, "use_ssl"))) {
 		for (i = 0; ssl_options[i].value; i++)
@@ -330,95 +265,26 @@ connect_to_server_wrapper (CamelService *service,
 				break;
 		mode = ssl_options[i].mode;
 		serv = (gchar *) ssl_options[i].serv;
-		port = ssl_options[i].port;
+		fallback_port = ssl_options[i].fallback_port;
 	} else {
 		mode = MODE_CLEAR;
 		serv = (gchar *) "pop3";
-		port = POP3S_PORT;
+		fallback_port = POP3S_PORT;
 	}
 
 	if (service->url->port) {
 		serv = g_alloca (16);
 		sprintf (serv, "%d", service->url->port);
-		port = NULL;
+		fallback_port = 0;
 	}
 
-	memset (&hints, 0, sizeof (hints));
-	hints.ai_socktype = SOCK_STREAM;
-	hints.ai_family = PF_UNSPEC;
-	ai = camel_getaddrinfo(service->url->host, serv, &hints, ex);
-	if (ai == NULL && port != NULL && camel_exception_get_id(ex) != CAMEL_EXCEPTION_USER_CANCEL) {
-		camel_exception_clear (ex);
-		ai = camel_getaddrinfo(service->url->host, port, &hints, ex);
-	}
-
-	if (ai == NULL)
-		return FALSE;
-
-	ret = connect_to_server (service, ai, mode, ex);
-
-	camel_freeaddrinfo (ai);
-
-	return ret;
-}
-
-extern CamelServiceAuthType camel_pop3_password_authtype;
-extern CamelServiceAuthType camel_pop3_apop_authtype;
-
-static GList *
-query_auth_types (CamelService *service,
-                  CamelException *ex)
-{
-	CamelServiceClass *service_class;
-	CamelPOP3Store *store = CAMEL_POP3_STORE (service);
-	GList *types = NULL;
-
-	/* Chain up to parent's query_auth_types() method. */
-	service_class = CAMEL_SERVICE_CLASS (camel_pop3_store_parent_class);
-	types = service_class->query_auth_types (service, ex);
-
-	if (camel_exception_is_set (ex))
-		return NULL;
-
-	if (connect_to_server_wrapper (service, NULL)) {
-		types = g_list_concat(types, g_list_copy(store->engine->auth));
-		pop3_disconnect (service, TRUE, NULL);
-	} else {
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,
-			_("Could not connect to POP server %s"),
-			service->url->host);
-	}
-
-	return types;
-}
-
-/**
- * camel_pop3_store_expunge:
- * @store: the store
- * @ex: a CamelException
- *
- * Expunge messages from the store. This will result in the connection
- * being closed, which may cause later commands to fail if they can't
- * reconnect.
- **/
-void
-camel_pop3_store_expunge (CamelPOP3Store *store, CamelException *ex)
-{
-	CamelPOP3Command *pc;
-
-	pc = camel_pop3_engine_command_new(store->engine, 0, NULL, NULL, "QUIT\r\n");
-	while (camel_pop3_engine_iterate(store->engine, NULL) > 0)
-		;
-	camel_pop3_engine_command_free(store->engine, pc);
-
-	camel_service_disconnect (CAMEL_SERVICE (store), FALSE, ex);
+	return connect_to_server (service, service->url->host, serv, fallback_port, mode, error);
 }
 
 static gint
 try_sasl (CamelPOP3Store *store,
           const gchar *mech,
-          CamelException *ex)
+          GError **error)
 {
 	CamelPOP3Stream *stream = store->engine->stream;
 	guchar *line, *resp;
@@ -428,8 +294,9 @@ try_sasl (CamelPOP3Store *store,
 
 	sasl = camel_sasl_new("pop", mech, (CamelService *)store);
 	if (sasl == NULL) {
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_SERVICE_URL_INVALID,
+		g_set_error (
+			error, CAMEL_SERVICE_ERROR,
+			CAMEL_SERVICE_ERROR_URL_INVALID,
 			_("Unable to connect to POP server %s: "
 			  "No support for requested authentication mechanism."),
 			CAMEL_SERVICE (store)->url->host);
@@ -449,8 +316,9 @@ try_sasl (CamelPOP3Store *store,
 
 			tmp = get_valid_utf8_error (
 				(gchar *) store->engine->line);
-			camel_exception_setv (
-				ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE,
+			g_set_error (
+				error, CAMEL_SERVICE_ERROR,
+				CAMEL_SERVICE_ERROR_CANT_AUTHENTICATE,
 				/* Translators: Last %s is an optional explanation beginning with ": " separator */
 				_("SASL '%s' Login failed for POP server %s%s"),
 				mech, CAMEL_SERVICE (store)->url->host,
@@ -463,12 +331,14 @@ try_sasl (CamelPOP3Store *store,
 		   its a protocol error, so fail, and try reset the server */
 		if (strncmp((gchar *) line, "+ ", 2) != 0
 		    || camel_sasl_get_authenticated(sasl)
-		    || (resp = (guchar *) camel_sasl_challenge_base64(sasl, (const gchar *) line+2, ex)) == NULL) {
+		    || (resp = (guchar *) camel_sasl_challenge_base64(sasl, (const gchar *) line+2, error)) == NULL) {
 			camel_stream_printf((CamelStream *)stream, "*\r\n");
 			camel_pop3_stream_line(stream, &line, &len);
-			camel_exception_setv (
-				ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE,
-				_("Cannot login to POP server %s: SASL Protocol error"),
+			g_set_error (
+				error, CAMEL_SERVICE_ERROR,
+				CAMEL_SERVICE_ERROR_CANT_AUTHENTICATE,
+				_("Cannot login to POP server %s: "
+				  "SASL Protocol error"),
 				CAMEL_SERVICE (store)->url->host);
 			goto done;
 		}
@@ -483,15 +353,10 @@ try_sasl (CamelPOP3Store *store,
 	return 0;
 
  ioerror:
-	if (errno == EINTR) {
-		camel_exception_set (
-			ex, CAMEL_EXCEPTION_USER_CANCEL, _("Canceled"));
-	} else {
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_SYSTEM,
-			_("Failed to authenticate on POP server %s: %s"),
-			CAMEL_SERVICE (store)->url->host, g_strerror (errno));
-	}
+	g_prefix_error (
+		error, _("Failed to authenticate on POP server %s: "),
+		CAMEL_SERVICE (store)->url->host);
+
  done:
 	g_object_unref (sasl);
 	return -1;
@@ -501,7 +366,7 @@ static gint
 pop3_try_authenticate (CamelService *service,
                        gboolean reprompt,
                        const gchar *errmsg,
-                       CamelException *ex)
+                       GError **error)
 {
 	CamelPOP3Store *store = (CamelPOP3Store *)service;
 	CamelPOP3Command *pcu = NULL, *pcp = NULL;
@@ -529,7 +394,7 @@ pop3_try_authenticate (CamelService *service,
 
 		service->url->passwd = camel_session_get_password (
 			camel_service_get_session (service), service,
-			NULL, full_prompt, "password", flags, ex);
+			NULL, full_prompt, "password", flags, error);
 
 		g_free (base_prompt);
 		g_free (full_prompt);
@@ -550,8 +415,9 @@ pop3_try_authenticate (CamelService *service,
 			if (!isascii((gint)*d)) {
 
 				/* README for Translators: The string APOP should not be translated */
-				camel_exception_setv (
-					ex, CAMEL_EXCEPTION_SERVICE_URL_INVALID,
+				g_set_error (
+					error, CAMEL_SERVICE_ERROR,
+					CAMEL_SERVICE_ERROR_URL_INVALID,
 					_("Unable to connect to POP server %s:	"
 					  "Invalid APOP ID received. Impersonation "
 					  "attack suspected. Please contact your admin."),
@@ -576,12 +442,13 @@ pop3_try_authenticate (CamelService *service,
 		while (l) {
 			auth = l->data;
 			if (strcmp(auth->authproto, service->url->authmech) == 0)
-				return try_sasl (store, service->url->authmech, ex);
+				return try_sasl (store, service->url->authmech, error);
 			l = l->next;
 		}
 
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_SERVICE_URL_INVALID,
+		g_set_error (
+			error, CAMEL_SERVICE_ERROR,
+			CAMEL_SERVICE_ERROR_URL_INVALID,
 			_("Unable to connect to POP server %s: "
 			  "No support for requested authentication mechanism."),
 			CAMEL_SERVICE (store)->url->host);
@@ -593,21 +460,26 @@ pop3_try_authenticate (CamelService *service,
 
 	if (status == -1) {
 		if (errno == EINTR) {
-			camel_exception_set (
-				ex, CAMEL_EXCEPTION_USER_CANCEL, _("Canceled"));
+			g_set_error (
+				error, G_IO_ERROR,
+				G_IO_ERROR_CANCELLED,
+				_("Cancelled"));
 		} else {
-			camel_exception_setv (
-				ex, CAMEL_EXCEPTION_SYSTEM,
+			g_set_error (
+				error, G_IO_ERROR,
+				g_io_error_from_errno (errno),
 				_("Unable to connect to POP server %s.\n"
 				  "Error sending password: %s"),
 				CAMEL_SERVICE (store)->url->host, errno ?
 				g_strerror (errno) : _("Unknown error"));
 		}
 	} else if (pcu && pcu->state != CAMEL_POP3_COMMAND_OK) {
-		gchar *tmp = get_valid_utf8_error ((gchar *) store->engine->line);
+		gchar *tmp;
 
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE,
+		tmp = get_valid_utf8_error ((gchar *) store->engine->line);
+		g_set_error (
+			error, CAMEL_SERVICE_ERROR,
+			CAMEL_SERVICE_ERROR_CANT_AUTHENTICATE,
 			/* Translators: Last %s is an optional explanation beginning with ": " separator */
 			_("Unable to connect to POP server %s.\n"
 			  "Error sending username%s"),
@@ -618,8 +490,9 @@ pop3_try_authenticate (CamelService *service,
 		gchar *tmp;
 
 		tmp = get_valid_utf8_error ((gchar *) store->engine->line);
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE,
+		g_set_error (
+			error, CAMEL_SERVICE_ERROR,
+			CAMEL_SERVICE_ERROR_CANT_AUTHENTICATE,
 			/* Translators: Last %s is an optional explanation beginning with ": " separator */
 			_("Unable to connect to POP server %s.\n"
 			  "Error sending password%s"),
@@ -636,24 +509,44 @@ pop3_try_authenticate (CamelService *service,
 	return status;
 }
 
+static void
+pop3_store_finalize (GObject *object)
+{
+	CamelPOP3Store *pop3_store = CAMEL_POP3_STORE (object);
+
+	/* force disconnect so we dont have it run later, after we've cleaned up some stuff */
+	/* SIGH */
+
+	camel_service_disconnect((CamelService *)pop3_store, TRUE, NULL);
+
+	if (pop3_store->engine)
+		g_object_unref (pop3_store->engine);
+	if (pop3_store->cache)
+		g_object_unref (pop3_store->cache);
+
+	/* Chain up to parent's finalize() method. */
+	G_OBJECT_CLASS (camel_pop3_store_parent_class)->finalize (object);
+}
+
 static gboolean
-pop3_connect (CamelService *service,
-              CamelException *ex)
+pop3_store_connect (CamelService *service,
+                    GError **error)
 {
 	CamelPOP3Store *store = (CamelPOP3Store *)service;
 	gboolean reprompt = FALSE;
 	CamelSession *session;
 	gchar *errbuf = NULL;
 	gint status;
+	GError *local_error = NULL;
 
 	session = camel_service_get_session (service);
 
 	if (store->cache == NULL) {
 		gchar *root;
 
-		root = camel_session_get_storage_path (session, service, ex);
+		root = camel_session_get_storage_path (session, service, error);
 		if (root) {
-			store->cache = camel_data_cache_new (root, ex);
+			store->cache = camel_data_cache_new (root, error);
 			g_free(root);
 			if (store->cache) {
 				/* Default cache expiry - 1 week or not visited in a day */
@@ -663,20 +556,23 @@ pop3_connect (CamelService *service,
 		}
 	}
 
-	if (!connect_to_server_wrapper (service, ex))
+	if (!connect_to_server_wrapper (service, error))
 		return FALSE;
 
 	while (1) {
 		status = pop3_try_authenticate (
-			service, reprompt, errbuf, ex);
+			service, reprompt, errbuf, &local_error);
 		g_free (errbuf);
 		errbuf = NULL;
 
 		/* we only re-prompt if we failed to authenticate,
 		 * any other error and we just abort */
-		if (status == 0 && camel_exception_get_id (ex) == CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE) {
-			errbuf = g_markup_printf_escaped ("%s\n\n", camel_exception_get_description (ex));
-			camel_exception_clear (ex);
+		if (g_error_matches (local_error, CAMEL_SERVICE_ERROR, CAMEL_SERVICE_ERROR_CANT_AUTHENTICATE)) {
+			gchar *tmp = camel_utf8_make_valid (local_error->message);
+			errbuf = g_markup_printf_escaped ("%s\n\n", tmp);
+			g_free (tmp);
+
+			g_clear_error (&local_error);
 
 			g_free (service->url->passwd);
 			service->url->passwd = NULL;
@@ -687,8 +583,9 @@ pop3_connect (CamelService *service,
 
 	g_free (errbuf);
 
-	if (status == -1 || camel_exception_is_set(ex)) {
-		camel_service_disconnect(service, TRUE, ex);
+	if (local_error != NULL) {
+		g_propagate_error (error, local_error);
+		camel_service_disconnect(service, TRUE, NULL);
 		return FALSE;
 	}
 
@@ -701,9 +598,9 @@ pop3_connect (CamelService *service,
 }
 
 static gboolean
-pop3_disconnect (CamelService *service,
-                 gboolean clean,
-                 CamelException *ex)
+pop3_store_disconnect (CamelService *service,
+                       gboolean clean,
+                       GError **error)
 {
 	CamelServiceClass *service_class;
 	CamelPOP3Store *store = CAMEL_POP3_STORE (service);
@@ -719,7 +616,7 @@ pop3_disconnect (CamelService *service,
 
 	/* Chain up to parent's disconnect() method. */
 	service_class = CAMEL_SERVICE_CLASS (camel_pop3_store_parent_class);
-	if (!service_class->disconnect (service, clean, ex))
+	if (!service_class->disconnect (service, clean, error))
 		return FALSE;
 
 	g_object_unref (store->engine);
@@ -728,32 +625,152 @@ pop3_disconnect (CamelService *service,
 	return TRUE;
 }
 
+static GList *
+pop3_store_query_auth_types (CamelService *service,
+                             GError **error)
+{
+	CamelServiceClass *service_class;
+	CamelPOP3Store *store = CAMEL_POP3_STORE (service);
+	GList *types = NULL;
+	GError *local_error = NULL;
+
+	/* Chain up to parent's query_auth_types() method. */
+	service_class = CAMEL_SERVICE_CLASS (camel_pop3_store_parent_class);
+	types = service_class->query_auth_types (service, &local_error);
+
+	if (local_error != NULL) {
+		g_propagate_error (error, local_error);
+		return NULL;
+	}
+
+	if (connect_to_server_wrapper (service, NULL)) {
+		types = g_list_concat(types, g_list_copy(store->engine->auth));
+		pop3_store_disconnect (service, TRUE, NULL);
+	} else {
+		g_set_error (
+			error, CAMEL_SERVICE_ERROR,
+			CAMEL_SERVICE_ERROR_UNAVAILABLE,
+			_("Could not connect to POP server %s"),
+			service->url->host);
+	}
+
+	return types;
+}
+
+static gchar *
+pop3_store_get_name (CamelService *service,
+                     gboolean brief)
+{
+	if (brief)
+		return g_strdup_printf (
+			_("POP3 server %s"),
+			service->url->host);
+	else
+		return g_strdup_printf (
+			_("POP3 server for %s on %s"),
+			service->url->user,
+			service->url->host);
+}
+
 static CamelFolder *
-get_folder (CamelStore *store,
-            const gchar *folder_name,
-            guint32 flags,
-            CamelException *ex)
+pop3_store_get_folder (CamelStore *store,
+                       const gchar *folder_name,
+                       guint32 flags,
+                       GError **error)
 {
 	if (g_ascii_strcasecmp (folder_name, "inbox") != 0) {
-		camel_exception_setv (
-			ex, CAMEL_EXCEPTION_FOLDER_INVALID,
+		g_set_error (
+			error, CAMEL_FOLDER_ERROR,
+			CAMEL_FOLDER_ERROR_INVALID,
 			_("No such folder '%s'."), folder_name);
 		return NULL;
 	}
 
-	return camel_pop3_folder_new (store, ex);
+	return camel_pop3_folder_new (store, error);
 }
 
 static CamelFolder *
-get_trash (CamelStore *store, CamelException *ex)
+pop3_store_get_trash (CamelStore *store,
+                      GError **error)
 {
 	/* no-op */
 	return NULL;
 }
 
+static CamelFolderInfo *
+pop3_store_get_folder_info (CamelStore *store,
+                            const gchar *top,
+                            guint32 flags,
+                            GError **error)
+{
+	g_set_error (
+		error, CAMEL_STORE_ERROR,
+		CAMEL_STORE_ERROR_NO_FOLDER,
+		_("POP3 stores have no folder hierarchy"));
+
+	return NULL;
+}
+
 static gboolean
-pop3_can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelException *ex)
+pop3_store_can_refresh_folder (CamelStore *store,
+                               CamelFolderInfo *info,
+                               GError **error)
 {
 	/* any pop3 folder can be refreshed */
 	return TRUE;
 }
+
+static void
+camel_pop3_store_class_init (CamelPOP3StoreClass *class)
+{
+	GObjectClass *object_class;
+	CamelServiceClass *service_class;
+	CamelStoreClass *store_class;
+
+	object_class = G_OBJECT_CLASS (class);
+	object_class->finalize = pop3_store_finalize;
+
+	service_class = CAMEL_SERVICE_CLASS (class);
+	service_class->connect = pop3_store_connect;
+	service_class->disconnect = pop3_store_disconnect;
+	service_class->query_auth_types = pop3_store_query_auth_types;
+	service_class->get_name = pop3_store_get_name;
+
+	store_class = CAMEL_STORE_CLASS (class);
+	store_class->get_folder = pop3_store_get_folder;
+	store_class->get_trash = pop3_store_get_trash;
+	store_class->get_folder_info = pop3_store_get_folder_info;
+	store_class->can_refresh_folder = pop3_store_can_refresh_folder;
+}
+
+static void
+camel_pop3_store_init (CamelPOP3Store *pop3_store)
+{
+}
+
+/**
+ * camel_pop3_store_expunge:
+ * @store: the store
+ * @error: return location for a #GError, or %NULL
+ *
+ * Expunge messages from the store. This will result in the connection
+ * being closed, which may cause later commands to fail if they can't
+ * reconnect.
+ **/
+void
+camel_pop3_store_expunge (CamelPOP3Store *store,
+                          GError **error)
+{
+	CamelPOP3Command *pc;
+
+	pc = camel_pop3_engine_command_new (
+		store->engine, 0, NULL, NULL, "QUIT\r\n");
+
+	while (camel_pop3_engine_iterate(store->engine, NULL) > 0)
+		;
+
+	camel_pop3_engine_command_free(store->engine, pc);
+
+	camel_service_disconnect (CAMEL_SERVICE (store), FALSE, error);
+}
+
